@@ -41,10 +41,10 @@ strcpy(conf->sqluser,"myuser");
 strcpy(conf->sqldb,"mydb");
 strcpy(conf->sqlpasswd,"mypasswd");
 strcpy(conf->message,"Greylisted");
+conf->training=0;
 conf->port=2525;
 conf->maxcon=100;
 conf->mini=60;
-conf->update=1;
 conf->syslog=1;
 conf->accept=1;
 conf->whitelist=1;
@@ -54,7 +54,6 @@ conf->loopback=1;
 conf->debug=0;
 conf->user[0]=0;
 conf->grp[0]=0;
-conf->lightd=0;
 conf->nbnet=0;
 conf->mxgrey=0;
 conf->keepdb=1;
@@ -83,15 +82,14 @@ while(fgets(buffer,1024,fic)!=NULL)
                 if(strcmp(buffer,"MESSAGE")==0) strcpy(conf->message,p+1);
                 if(strcmp(buffer,"PORT")==0) conf->port=atoi(p+1);
                 if(strcmp(buffer,"MAXCON")==0) conf->maxcon=atoi(p+1);
+                if(strcmp(buffer,"TRAINING")==0) conf->training=atoi(p+1);
                 if(strcmp(buffer,"MINTIME")==0) conf->mini=atol(p+1);
-                if(strcmp(buffer,"UPDATE")==0) conf->update=atoi(p+1);
                 if(strcmp(buffer,"KEEPDBOPEN")==0) conf->keepdb=atoi(p+1);
                 if(strcmp(buffer,"MXGREY")==0) conf->mxgrey=atoi(p+1);
                 if(strcmp(buffer,"SYSLOG")==0) conf->syslog=atoi(p+1);
                 if(strcmp(buffer,"ERRACCEPT")==0) conf->accept=atoi(p+1);
                 if(strcmp(buffer,"WHITELIST")==0) conf->whitelist=atoi(p+1);
                 if(strcmp(buffer,"LIGHTGREY")==0) conf->light=atoi(p+1);
-                if(strcmp(buffer,"LIGHTGREYDOMAIN")==0) conf->lightd=atoi(p+1);
                 if(strcmp(buffer,"LOOPBACKONLY")==0) conf->loopback=atoi(p+1);
 		#ifdef HAVE_SYSLOG_H
                 if(strcmp(buffer,"FACILITY")==0)
@@ -104,12 +102,6 @@ while(fgets(buffer,1024,fic)!=NULL)
 
 fclose(fic);
 
-if(conf->mxgrey==1)
-	{
-	conf->update=1;
-	conf->lightd=0;
-	}
-
 return(0);
 }
 
