@@ -37,7 +37,7 @@
 #define MSGLOCALWL	1
 #define MSGDNSWL	2
 
-#define VERSION "1.5.2"
+#define VERSION "1.6"
 
 typedef struct network
 {
@@ -49,18 +49,17 @@ typedef struct config
 {
 	int port;			// Port to listen to
 	int maxcon;			// max # of connections
-	int update;			// Do we update the database 
 	long mini;			// Minimum time for greylist
 	int syslog;			// Shall we write to the syslog
 	int accept;			// Shall we return OK in case of error
 	int whitelist;			// Shall we lookup the whitelist table
 	int light;			// Shall we use light greylisting ?
-	int lightd;			// Shall we use lightgrey domain ?
 	int facility;			// Syslog facility to use
 	int loopback;			// Shall we bind only to loopback
 	int keepdb;			// Shall we keep the db open
 	int mxgrey;			// Shall we use the mexgrey algorithm ?
 	int debug;			// Shall we display debug informations 
+	int training;			// Shall we activate training mode
 	char dnswl[512];		// The domain to use if we do DNSWL
 	char message[512];		// The text we display
 	char sqlhost[128];		// SQL server
