@@ -99,12 +99,12 @@ if(conf.user[0]!=0)
 
 if(SQLConnect(conf.sqlhost,conf.sqluser,conf.sqlpasswd,conf.sqldb)<0)
                 {
-                printf("Connection to SQL Server failed\n");
-                exit(10);
+                printf("WARNING Connection to SQL Server failed\n");
+                printf("KEEPDBOPEN is now forced to 0\n");
+		conf.keepdb=0;
                 }
 
-
-if(conf.debug==1) printf("Connected succesfuly to MySQL server\n");
+else if(conf.debug==1) printf("Connected succesfuly to MySQL server\n");
 
 //
 // Now we do what we have to do
@@ -326,12 +326,22 @@ if(n<0)
 
 if(n==0)
 	{
-	if(atoi(cnf->message)==0) snprintf(buff,sizeof(buff)-1,"action=defer_if_permit %s\n\n",cnf->message);
-	else snprintf(buff,sizeof(buff)-1,"action=%s\n\n",cnf->message);
-
-        WriteSocket(s,buff,strlen(buff),TOUT);
         if(cnf->syslog==1) Log(cnf,recipient,sender,ip,MSGGREYLIST);
 	if(cnf->debug==1) printf("%d: Decision is to greylist\n",pid);
+
+	if(cnf->training==0)
+		{
+		if(atoi(cnf->message)<400 || atoi(cnf->message)>499)
+		snprintf(buff,sizeof(buff)-1,"action=defer_if_permit %s\n\n",cnf->message);
+		else snprintf(buff,sizeof(buff)-1,"action=%s\n\n",cnf->message);
+		}
+	else
+		{
+		if(cnf->debug==1) printf("%d: Training mode, sending dunno\n",pid);
+		strcpy(buff,"action=dunno\n\n");
+		}
+
+        WriteSocket(s,buff,strlen(buff),TOUT);
         }
 else 
 	{
